=================
Masakari Policies
=================

The following is an overview of all available policies in masakari.
For a sample configuration file, refer to :doc:`sample_policy`.

.. show-policy::
   :config-file: etc/masakari/masakari-policy-generator.conf
